@@ -4,10 +4,14 @@ package Thread::Conveyor::Array;
 # Make sure we have version info for this module
 # Make sure we do everything by the book from now on
 
-our @ISA : unique = qw(Thread::Conveyor);
-our $VERSION : unique = '0.08';
+our @ISA = qw(Thread::Conveyor);
+our $VERSION = '0.09';
 use strict;
 
+# Make sure we only load stuff when we actually need it
+
+use AutoLoader ();
+
 # Make sure we can share and wait and signal
 
 use threads::shared qw(cond_wait cond_signal cond_broadcast);
@@ -37,6 +41,12 @@ sub new {
 
 #---------------------------------------------------------------------------
 
+# AutoLoader takes over from here
+
+__END__
+
+#---------------------------------------------------------------------------
+
 # Object methods
 
 #---------------------------------------------------------------------------
@@ -198,6 +208,23 @@ sub minboxes {
     die "Cannot change throttling on a belt that was created unthrottled";
 } #minboxes
 
+#---------------------------------------------------------------------------
+#  IN: 1 instantiated object
+
+sub shutdown {} #shutdown
+
+#---------------------------------------------------------------------------
+#  IN: 1 instantiated object
+# OUT: 1 thread object associated with belt (always undef)
+
+sub thread { undef } #thread
+
+#---------------------------------------------------------------------------
+#  IN: 1 instantiated object
+# OUT: 1 thread id of thread object associated with belt (always undef)
+
+sub tid { undef } #tid
+
 #---------------------------------------------------------------------------
 
 # Internal subroutines
@@ -240,8 +267,6 @@ sub _clean {
 
 #---------------------------------------------------------------------------
 
-__END__
-
 =head1 NAME
 
 Thread::Conveyor::Array - array implementation of Thread::Conveyor
