@@ -4,10 +4,14 @@ package Thread::Conveyor::Thread;
 # Make sure we have version info for this module
 # Make sure we do everything by the book from now on
 
-our @ISA : unique = qw(Thread::Conveyor);
-our $VERSION : unique = '0.08';
+our @ISA = qw(Thread::Conveyor);
+our $VERSION = '0.09';
 use strict;
 
+# Make sure we only load stuff when we actually need it
+
+use AutoLoader ();
+
 # Make sure we can wait and signal
 
 use threads::shared qw(cond_wait cond_signal);
@@ -22,6 +26,35 @@ my $cloned = 0;
 
 #---------------------------------------------------------------------------
 
+# Routines for standard Perl features
+
+#---------------------------------------------------------------------------
+#  IN: 1 namespace being cloned (ignored)
+
+sub CLONE { $cloned++ } #CLONE
+
+#---------------------------------------------------------------------------
+#  IN: 1 instantiated object
+
+sub DESTROY {
+
+# Return now if we're in a rogue DESTROY
+
+    return unless UNIVERSAL::isa( $_[0],__PACKAGE__ ); #HACK
+
+# Obtain the object
+# Return now if we're not allowed to run DESTROY
+
+    my $self = shift;
+    return unless $self->{'cloned'} == $cloned;
+
+# Tell the thread to quit now
+
+    $self->shutdown( 1 );
+} #DESTROY
+
+#---------------------------------------------------------------------------
+
 # Class methods
 
 #---------------------------------------------------------------------------
@@ -63,6 +96,12 @@ sub new {
 
 #---------------------------------------------------------------------------
 
+# AutoLoader takes over from here
+
+__END__
+
+#---------------------------------------------------------------------------
+
 # Object methods
 
 #---------------------------------------------------------------------------
@@ -449,37 +488,6 @@ sub _handler {
 
 #---------------------------------------------------------------------------
 
-# Routines for standard Perl features
-
-#---------------------------------------------------------------------------
-#  IN: 1 namespace being cloned (ignored)
-
-sub CLONE { $cloned++ } #CLONE
-
-#---------------------------------------------------------------------------
-#  IN: 1 instantiated object
-
-sub DESTROY {
-
-# Return now if we're in a rogue DESTROY
-
-    return unless UNIVERSAL::isa( $_[0],__PACKAGE__ ); #HACK
-
-# Obtain the object
-# Return now if we're not allowed to run DESTROY
-
-    my $self = shift;
-    return unless $self->{'cloned'} == $cloned;
-
-# Tell the thread to quit now
-
-    $self->shutdown( 1 );
-} #DESTROY
-
-#---------------------------------------------------------------------------
-
-__END__
-
 =head1 NAME
 
 Thread::Conveyor::Thread - thread implementation of Thread::Conveyor
