@@ -4,10 +4,14 @@ package Thread::Conveyor::Throttled;
 # Make sure we have version info for this module
 # Make sure we do everything by the book from now on
 
-our @ISA : unique = qw(Thread::Conveyor);
-our $VERSION : unique = '0.08';
+our @ISA = qw(Thread::Conveyor);
+our $VERSION = '0.09';
 use strict;
 
+# Make sure we only load stuff when we actually need it
+
+use AutoLoader ();
+
 # Make sure we can do a shared array belt
 # Make sure we can wait and broadcast
 
@@ -42,6 +46,12 @@ sub new {
 
 #---------------------------------------------------------------------------
 
+# AutoLoader takes over from here
+
+__END__
+
+#---------------------------------------------------------------------------
+
 # object methods
 
 #---------------------------------------------------------------------------
@@ -153,6 +163,23 @@ sub minboxes {
     $self->{'minboxes'};
 } #minboxes
 
+#---------------------------------------------------------------------------
+#  IN: 1 instantiated object
+
+sub shutdown {} #shutdown
+
+#---------------------------------------------------------------------------
+#  IN: 1 instantiated object
+# OUT: 1 thread object associated with belt (always undef)
+
+sub thread { undef } #thread
+
+#---------------------------------------------------------------------------
+#  IN: 1 instantiated object
+# OUT: 1 thread id of thread object associated with belt (always undef)
+
+sub tid { undef } #tid
+
 #---------------------------------------------------------------------------
 
 # internal methods
@@ -237,8 +264,6 @@ sub _clean { shift->{'belt'}->_clean } #_clean
 
 #---------------------------------------------------------------------------
 
-__END__
-
 =head1 NAME
 
 Thread::Conveyor::Throttled - helper class of Thread::Conveyor
